@@ -28,6 +28,10 @@ class Invoice(ObjectBase):
     def issued_at(self):
         return self._get_property("issuedAt")
 
+    @property
+    def paid_at(self):
+        return self._get_property("paidAt")
+
     @property
     def due_at(self):
         return self._get_property("dueAt")
