@@ -2,9 +2,8 @@ from ..error import EmbedNotFound
 from ..resources.order_lines import OrderLines
 from ..resources.order_payments import OrderPayments
 from ..resources.order_refunds import OrderRefunds
-from ..resources.shipments import Shipments
 from .base import ObjectBase
-from .list import List
+from .list import ObjectList
 from .order_line import OrderLine
 from .payment import Payment
 
@@ -164,6 +163,9 @@ class Order(ObjectBase):
     def is_expired(self):
         return self._get_property("status") == self.STATUS_EXPIRED
 
+    def has_refunds(self):
+        return self.amount_refunded is not None
+
     def create_refund(self, data=None, **params):
         """Create a refund for the order. When no data arg is given, a refund for all order lines is assumed."""
         if data is None:
@@ -186,8 +188,9 @@ class Order(ObjectBase):
 
     @property
     def refunds(self):
-        refunds = OrderRefunds(self.client).on(self).list()
-        return refunds
+        if not self.has_refunds():
+            return ObjectList({}, None)
+        return OrderRefunds(self.client).on(self).list()
 
     @property
     def lines(self):
@@ -198,7 +201,7 @@ class Order(ObjectBase):
             },
             "count": len(lines),
         }
-        return List(result, OrderLine, self.client)
+        return ObjectList(result, OrderLine, self.client)
 
     def update_line(self, resource_id, data):
         """Update a line for an order."""
@@ -207,21 +210,21 @@ class Order(ObjectBase):
     @property
     def shipments(self):
         """Retrieve all shipments for an order."""
-        return Shipments(self.client).on(self).list()
+        return self.client.shipments.on(self).list()
 
     def create_shipment(self, data=None):
         """Create a shipment for an order. When no data arg is given, a shipment for all order lines is assumed."""
         if data is None:
             data = {"lines": []}
-        return Shipments(self.client).on(self).create(data)
+        return self.client.shipments.on(self).create(data)
 
     def get_shipment(self, resource_id):
         """Retrieve a single shipment by a shipment's ID."""
-        return Shipments(self.client).on(self).get(resource_id)
+        return self.client.shipments.on(self).get(resource_id)
 
     def update_shipment(self, resource_id, data):
         """Update the tracking information of a shipment."""
-        return Shipments(self.client).on(self).update(resource_id, data)
+        return self.client.shipments.on(self).update(resource_id, data)
 
     @property
     def payments(self):
@@ -240,7 +243,7 @@ class Order(ObjectBase):
             },
             "count": len(payments),
         }
-        return List(result, Payment, self.client)
+        return ObjectList(result, Payment, self.client)
 
     def create_payment(self, data):
         """Creates a new payment object for an order."""
