@@ -36,6 +36,10 @@ class Organization(ObjectBase):
     def vat_number(self):
         return self._get_property("vatNumber")
 
+    @property
+    def vat_regulation(self):
+        return self._get_property("vatRegulation")
+
     @property
     def dashboard(self):
         return self._get_link("dashboard")
