@@ -1,9 +1,9 @@
 from ..error import IdentifierError
 from ..objects.payment import Payment
-from .base import Base
+from .base import ResourceBase
 
 
-class Payments(Base):
+class Payments(ResourceBase):
     RESOURCE_ID_PREFIX = "tr_"
 
     def get_resource_object(self, result):
@@ -12,9 +12,7 @@ class Payments(Base):
     def get(self, payment_id, **params):
         if not payment_id or not payment_id.startswith(self.RESOURCE_ID_PREFIX):
             raise IdentifierError(
-                "Invalid payment ID: '{id}'. A payment ID should start with '{prefix}'.".format(
-                    id=payment_id, prefix=self.RESOURCE_ID_PREFIX
-                )
+                f"Invalid payment ID: '{payment_id}'. A payment ID should start with '{self.RESOURCE_ID_PREFIX}'."
             )
         return super().get(payment_id, **params)
 
@@ -26,9 +24,7 @@ class Payments(Base):
         """
         if not payment_id or not payment_id.startswith(self.RESOURCE_ID_PREFIX):
             raise IdentifierError(
-                "Invalid payment ID: '{id}'. A payment ID should start with '{prefix}'.".format(
-                    id=payment_id, prefix=self.RESOURCE_ID_PREFIX
-                )
+                f"Invalid payment ID: '{payment_id}'. A payment ID should start with '{self.RESOURCE_ID_PREFIX}'."
             )
         result = super().delete(payment_id, data)
         return self.get_resource_object(result)
